## Read some test data
X <- read.csv("inputPRBS1.csv", sep=";")

require(ctsmr)
## Generate a new object of class ctsm
model <- ctsm()
## Add a system equation and thereby also a state
model$addSystem(dTi ~ ( 1/(Ci*Ria)*(Ta-Ti) )*dt + exp(p11)*dw1)
## Set the names of the inputs
model$addInput(Ta)

## ## Alternatively add the heater
## model$addSystem(dTi ~ ( 1/(Ci*Ria)*(Ta-Ti) + 1/Ci * Ph )*dt + exp(p11)*dw1)
## model$addInput(Ta,Ph)

## Set the observation equation: Ti is the state, yTi is the measured output
model$addObs(yTi ~ Ti)
## Set the variance of the measurement error
model$setVariance(yTi ~ exp(e11))
## Set the initial value (for the optimization) of the value of the state at the starting   time point
##model$setParameter(  Ti = c(init=15  ,lb=0     ,ub=25 ) )
model$setParameter(  Ti = c(init=X$yTi[1] ,lb=0     ,ub=25 ) )
## Set the initial value for the optimization
model$setParameter(  Ci = c(init=10   ,lb=1E-5  ,ub=500 ) )
model$setParameter( Ria = c(init=20  ,lb=1     ,ub=1E4) )
model$setParameter( p11 = c(init=1   ,lb=-30   ,ub=10 ) )
model$setParameter( e11 = c(init=-1  ,lb=-50   ,ub=10 ) )


## Needs to be runned for simulate to work
model$AnalyseModel()

## Make a fit object to pass to simulate.ctsmr
fit <- list()
fit$model <- model
fit$xm <- model$ParameterValues$initial
names(fit$xm) <- row.names(model$ParameterValues)
## Can be nessary such that xm has the right length
fit$xm <- fit$xm[model$pars]
class(fit) <- "ctsmr"
## Simulate with the initial values
sim <- simulate(fit, newdata=X)
str(sim)
## or
sim2 <- ctsmr:::simulate.ctsmr(fit, newdata=X)
str(sim2)

## Plot the simulated output
plot(X$t, sim$output$sim$yTi, type='l', ylim=range(sim$output$sim$yTi, X$yTi, X$Ta))
lines(X$t, X$yTi, type='l', col=2)
lines(X$t, X$Ta, type='l')

## Now go up and uncomment the lines with code with the heater (uncomment the two similar) and run again
## Try to change the parameter values
